@@ -17,7 +17,9 @@ def handle_status_code(func):
         try:
             return func(*args, **kwargs)
         except Exception as err:
-            if err.response.status_code == 401:
+            if not err.response:
+                raise Exception(err)
+            elif err.response.status_code == 401:
                 raise Exception("API credentials not correct.")
             else:
                 raise Exception(
