@@ -91,9 +91,9 @@ def flatten_invoice(invoice, validation):
                     k,
                 )
             elif isinstance(v, list):
-                for counter, list_item in enumerate(v):
-                    # TODO: fix terms and ibanAll
-                    if k != "terms" and k != "ibanAll":
+                # items, taxes, terms
+                if all(isinstance(list_item, dict) for list_item in v):
+                    for counter, list_item in enumerate(v):
                         temp_dict = {}
                         for item, value in list_item.items():
                             temp_dict[f"{k}_{item}_{counter}"] = value
@@ -107,6 +107,13 @@ def flatten_invoice(invoice, validation):
                             else None,
                             return_dict,
                         )
+                # ibanAll enc
+                elif all(isinstance(list_item, str) for list_item in v):
+                    for counter, list_item in enumerate(v):
+                        _dict[f"{k}_{counter+1}_idx"] = (list_item, None, None)
+                # Undefined datastructure
+                else:
+                    pass
             else:
                 try:
                     # dirty solution, assumes no invoice extractor response field got underscore
